.. _helper:

helper
======

.. module:: helper
   :platform: Unix
   :synopsis: Helper functions for processing wave and cube values.

Overview
--------

The `helper` module contains utility functions to assist with processing wave values, normalizing data, and performing feature-based image registration.

Functions
---------

.. autofunction:: wizard._utils.helper.find_nex_greater_wave
.. autofunction:: wizard._utils.helper.find_nex_smaller_wave
.. autofunction:: wizard._utils.helper.normalize
.. autofunction:: wizard._utils.helper.feature_regestration
